diff roundup/scripts/roundup_server.py @ 2774:22c381f3f448

respect function argument 'port' in run()
author Alexander Smishlajev <a1s@users.sourceforge.net>
date Mon, 18 Oct 2004 07:43:58 +0000
parents 6fb4b692c133
children 9a6b451b1ba6
line wrap: on
line diff
--- a/roundup/scripts/roundup_server.py	Sun Oct 17 18:22:32 2004 +0000
+++ b/roundup/scripts/roundup_server.py	Mon Oct 18 07:43:58 2004 +0000
@@ -17,7 +17,7 @@
 
 """Command-line script that runs a server over roundup.cgi.client.
 
-$Id: roundup_server.py,v 1.65 2004-10-17 18:22:32 a1s Exp $
+$Id: roundup_server.py,v 1.66 2004-10-18 07:43:58 a1s Exp $
 """
 __docformat__ = 'restructuredtext'
 
@@ -592,8 +592,12 @@
 
     RoundupRequestHandler.LOG_IPADDRESS = not config.LOG_HOSTNAMES
 
-    # obtain server before changing user id - allows to use port <
-    # 1024 if started as root
+    # port number in function arguments overrides config and command line
+    if port is not undefined:
+        config.PORT = port
+
+    # obtain server before changing user id - allows
+    # to use port < 1024 if started as root
     try:
         httpd = server_class((config.HOST, config.PORT), RoundupRequestHandler)
     except socket.error, e:

Roundup Issue Tracker: http://roundup-tracker.org/